==> SiteBar-3.2.6.tar.bz2: SiteBar-3.2.6/locale/ca_ES/para.inc.php <==
<?php

$para = array();

$para['index::tip'] = <<<_P
Usa aquesta pàgina per executar o instalar al teu navegador aquesta instància del servidor de bookmarks SiteBar. Es recomana d'afegir als preferits un dels enllaços marcats amb "*" en lloc d'aquesta mateixa pàgina. Aquesta pàgina es pot obrir des de la finestra de SiteBar fent-hi un clic al logotip de dalt.
_P;

$para['index::any_browser'] = <<<_P
Usa <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>* en aquesta finestra - o obre-ho en una finestra emergent <a title="SiteBar" href="%s">SiteBar</a>*
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Instala</a> / <a href="?install=0">Desinstala</a> de la barra de l'Explorer i el menú de context - necessita canvis al registre i reinici del sistema per totes les característiques. Depenent dels teus drets potser només seran instalades algunes característiques. <p class='comment'>Obre la barra SiteBar de l'Explorador des del menú View/Explorer Bar o usa la funció <b>Customize...</b> per mostrar a la barra d'eines el botó d'activació del panell SiteBar. Clica amb el botó dret a la pàgina o damunt un enllaç per afegir-ho a SiteBar. </p>
_P;

$para['index::ie_search'] = <<<_P
Afegeix <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))"> SiteBar</a>* temporalment a la barra de cerca de l'Explorer. <p class='comment'>Usa quan no tinguis prous drets per usar l'instalador de dalt.</p>
_P;

$para['index::mozilla'] = <<<_P
Afegeix una <a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
barra lateral</a> compatible amb Mozilla/Netscape - mostra usant F9.
<p class='comment'>Els usuaris de Mozilla Firefox han d'usar l'enllaç de dalt per crear un bookmark que
s'obri a la barra lateral en ser clicat. Mozillazine <a href="http://forums.mozillazine.org/viewtopic.php?t=36166">topic</a> descriu com usar l'extensió de barra lateral <a href="http://www.sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBar</a> i l'extensió de menu 
<a href="http://www.sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLinks</a> amb SiteBar
</p>
_P;

$para['index::opera'] = <<<_P
Afegeix al <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a> de Opera com a barra lateral. <p class='comment'>Usa Ctrl + clic en lloc de clic dret per veure el menú contextual de carpeta i enllaç.</p>
_P;

$para['index::myie2_install'] = <<<_P
Descarrega <a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">barra lateral</a> feta a mida i/o <a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">afegeix el tab actual</a> al plugin de la barra de tasques SiteBar.
_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Afegeix pàgina a SiteBar</a>* - Clica amb el botó dret aquest enllaç i afegeix-lo a la teva barra de favorits/bookmarks. Et permetrà més tard afegir un enllaç al SiteBar cap a la pàgina que estiguis veient al navegador. Els usuaris de MS IE poden usar també l'instalador i el menú de context.
_P;

$para['index::copyright2'] = <<<_P
Copyright &copy; 2003,2004 <a href='http://brablc.com/'>Ondřej Brablc</a> i l'<a href='http://www.sitebar.org/team.php'>Equip de SiteBar</a>. Fòrum de <a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>suport</a>.
_P;

$para['command::contact'] = <<<_P
Missatge:

%s


--
Instalació de SiteBar a %s.
_P;

$para['command::contact_group'] = <<<_P
Grup: %s
Missatge:

%s


--
Instalació de SiteBar a %s.
_P;

$para['command::delete_account'] = <<<_P
<h3>Vols esborrar de veritat el teu compte?</h3>
No hi ha manera de desfer aquest canvi!<p>
Tots els teus arbres restant seran donats a l'administrador del sistema.
_P;

$para['command::email_link_href'] = <<<_P
<p>Envia correu a través del teu
<a href='mailto:?subject=Pàgina web: %s&amp;body=He trobat una pàgina web que et pot interesar. Fés un cop d'ull a: %s -- Enviat via SiteBar a %s Open Source Bookmark Server http://www.sitebar.org '>client de correu</a> per defecte.
_P;

$para['command::email_link'] = <<<_P
He trobat una pàgina web que et pot interesar.
Fés un cop d'ull a:

 "%s" %s

%s

--
Enviat via SiteBar a %s
Open Source Bookmark Server http://www.sitebar.org
_P;

$para['command::verify_email'] = <<<_P
Has demanat una validació de l'adreça de correu que et permetrà afegir-te als grups amb expresions regulars d'auto-afegit i et permetrà fer us de les caracteristiques de correu de SiteBar.

Sisplau clica al següent enllaç per verificar la teva adreça de correu:
 %s
_P;

$para['command::import_bk'] = <<<_P
<br>
Els favorits locals poden ser exportats a un fitxer local usant una
<a href='javascript:window.external.ImportExportFavorites(false,"")'>funció</a> javascript.
_P;

$para['command::export_bk'] = <<<_P
<br>
Els bookmarks exportats poden ser importats als favorits locals usant una <a href='javascript:window.external.ImportExportFavorites(true,"")'>funció</a> javascript.
_P;

$para['command::noiconv'] = <<<_P
<br>
Conversió de pàgina de codis no instalada en aquest servidor de SiteBar.
<br>
_P;

$para['command::security_legend'] = <<<_P
Dreta:
<strong>R</strong>ead (llegeix),
<strong>A</strong>dd (afegeix),
<strong>M</strong>odify (modifica),
<strong>D</strong>elete (esborra),
<strong>P</strong>urge (purga),
<strong>G</strong>rant (garanteix)
_P;

$para['command::purge_cache'] = <<<_P
<h3>Realment vols eliminar tots els favicons de la caché?</h3>
_P;

$para['usermanager::auto_verify_email'] = <<<_P
La teva adreça de correu concorda amb les regles d'auto afiliació als següents grups tancats:
 %s.

Per tal d'aprovar la teva afiliació, la teva adreça de correu ha de ser verificada. Sisplau, clica en l'enllaç següent per verificar-la:
 %s
_P;

$para['usermanager::signup_info'] = <<<_P
L'usuari "%s" s'ha registrat a la teva instalació de Sitebar a %s.
_P;

$para['hook::statistics'] = <<<_P
Arrels {roots_total}.
Carpetes {nodes_shown}/{nodes_total}.
Enllaços {links_shown}/{links_total}.
Usuaris {users}.
Grups {groups}.
Queris SQL {queries}.
Base de dades/Temps total {time_db}/{time total} sec ({time_pct}%).
_P;

?>

==> SiteBar-3.3.3.tar.bz2: SiteBar-3.3.3/locale/ca_ES/para.inc.php <==
<?php

$para = array();

$para['index::tip'] = <<<_P
Usa aquesta pàgina per executar o instalar al teu navegador aquesta instància del servidor de bookmarks SiteBar. Es recomana d'afegir als preferits un dels enllaços marcats amb "*" en lloc d'aquesta mateixa pàgina. Aquesta pàgina es pot obrir des de la finestra de SiteBar fent-hi un clic al logotip de dalt.
_P;

$para['index::any_browser'] = <<<_P
Usa <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>* en aquesta finestra - o obre-ho en una finestra emergent <a title="SiteBar" href="%s">SiteBar</a>*
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Instala</a> / <a href="?install=0">Desinstala</a> de la barra de l'Explorer i el menú de context - necessita canvis al registre i reinici del sistema per totes les característiques. Depenent dels teus drets potser només seran instalades algunes característiques. <p class='comment'>Obre la barra SiteBar de l'Explorador des del menú View/Explorer Bar o usa la funció <b>Customize...</b> per mostrar a la barra d'eines el botó d'activació del panell SiteBar. Clica amb el botó dret a la pàgina o damunt un enllaç per afegir-ho a SiteBar. </p>
_P;

$para['index::ie_search'] = <<<_P
Afegeix <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))"> SiteBar</a>* temporalment a la barra de cerca de l'Explorer. <p class='comment'>Usa quan no tinguis prous drets per usar l'instalador de dalt.</p>
_P;

$para['index::mozilla'] = <<<_P
Afegeix una <a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
barra lateral</a> compatible amb Mozilla/Netscape - mostra usant F9.
<p class='comment'>Els usuaris de Mozilla Firefox han d'usar l'enllaç de dalt per crear un bookmark que
s'obri a la barra lateral en ser clicat. Mozillazine <a href="http://forums.mozillazine.org/viewtopic.php?t=36166">topic</a> descriu com usar l'extensió de barra lateral <a href="http://sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBar</a> i l'extensió de menu 
<a href="http://sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLinks</a> amb SiteBar
</p>
_P;

$para['index::opera'] = <<<_P
Afegeix al <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a> de Opera com a barra lateral. <p class='comment'>Usa Ctrl + clic en lloc de clic dret per veure el menú contextual de carpeta i enllaç.</p>
_P;

$para['index::myie2_install'] = <<<_P
Descarrega <a href="http://sitebar.org/plugin/myie2/?sidebar=%s">barra lateral</a> feta a mida i/o <a href="http://sitebar.org/plugin/myie2/?toolbar=%s">afegeix el tab actual</a> al plugin de la barra de tasques SiteBar.
_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Afegeix pàgina a SiteBar</a>* - Clica amb el botó dret aquest enllaç i afegeix-lo a la teva barra de favorits/bookmarks. Et permetrà més tard afegir un enllaç al SiteBar cap a la pàgina que estiguis veient al navegador. Els usuaris de MS IE poden usar també l'instalador i el menú de context.
_P;

$para['index::copyright2'] = <<<_P
Copyright &copy; 2003-2005 <a href='http://brablc.com/'>Ondřej Brablc</a> i l'<a href='http://sitebar.org/team.php'>Equip de SiteBar</a>. Fòrum de <a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>suport</a>.
_P;

$para['command::contact'] = <<<_P
Missatge:

%s


--
Instalació de SiteBar a %s.
_P;

$para['command::contact_group'] = <<<_P
Grup: %s
Missatge:

%s


--
Instalació de SiteBar a %s.
_P;

$para['command::delete_account'] = <<<_P
<h3>Vols esborrar de veritat el teu compte?</h3>
No hi ha manera de desfer aquest canvi!<p>
Tots els teus arbres restant seran donats a l'administrador del sistema.
_P;

$para['command::email_link_href'] = <<<_P
<p>Envia correu a través del teu
<a href='mailto:?subject=Pàgina web: %s&body=He trobat una pàgina web que et pot interesar. Fés un cop d'ull a: %s -- Enviat via SiteBar a %s Open Source Bookmark Server http://sitebar.org '>client de correu</a> per defecte.
_P;

$para['command::email_link'] = <<<_P
He trobat una pàgina web que et pot interesar.
Fés un cop d'ull a:

 "%s" %s

%s

--
Enviat via SiteBar a %s
Open Source Bookmark Server http://sitebar.org
_P;

$para['command::verify_email'] = <<<_P
Has demanat una validació de l'adreça de correu que et permetrà afegir-te als grups amb expresions regulars d'auto-afegit i et permetrà fer us de les caracteristiques de correu de SiteBar.

Sisplau clica al següent enllaç per verificar la teva adreça de correu:
 %s
_P;

$para['command::import_bk'] = <<<_P
<br>
Els favorits locals poden ser exportats a un fitxer local usant una
<a href='javascript:window.external.ImportExportFavorites(false,"")'>funció</a> javascript.
_P;

$para['command::export_bk'] = <<<_P
<br>
Els bookmarks exportats poden ser importats als favorits locals usant una <a href='javascript:window.external.ImportExportFavorites(true,"")'>funció</a> javascript.
_P;

$para['command::export_bk_ie_hint'] = <<<_P
L'Internet Explorer pot importar/exportar bookmarks en el format de fitxer de bookmarks de netscape.
De totes formes, ha de ser en la codificació nativa de Windows, el UTF-8 usat per defecte no funcionarà.<br>
_P;

$para['command::noiconv'] = <<<_P
<br>
Conversió de pàgina de codis no instalada en aquest servidor de SiteBar.
<br>
_P;

$para['command::security_legend'] = <<<_P
Dreta:
<strong>R</strong>ead (llegeix),
<strong>A</strong>dd (afegeix),
<strong>M</strong>odify (modifica),
<strong>D</strong>elete (esborra),
<strong>P</strong>urge (purga),
<strong>G</strong>rant (garanteix)
_P;

$para['command::purge_cache'] = <<<_P
<h3>Realment vols eliminar tots els favicons de la caché?</h3>
_P;

$para['usermanager::auto_verify_email'] = <<<_P
La teva adreça de correu concorda amb les regles d'auto afiliació als següents grups tancats:
 %s.

Per tal d'aprovar la teva afiliació, la teva adreça de correu ha de ser verificada. Sisplau, clica en l'enllaç següent per verificar-la:
 %s
_P;

$para['usermanager::signup_info'] = <<<_P
L'usuari "%s" s'ha registrat a la teva instalació de Sitebar a %s.
_P;

$para['hook::statistics'] = <<<_P
Arrels {roots_total}.
Carpetes {nodes_shown}/{nodes_total}.
Enllaços {links_shown}/{links_total}.
Usuaris {users}.
Grups {groups}.
Queris SQL {queries}.
Base de dades/Temps total {time_db}/{time total} sec ({time_pct}%).
_P;

?>
